--[[
	
	info.options = the options table
	info[0] = slash command
	info[1] = first group name
	info[#info] = current option name
	info.arg
	info.handler
	info.type
	info.option = current option
	info.uiType
	info.uiName
	
	Currently inherited are: set, get, func, confirm, validate, disabled, hidden
	
]]--

--to do - shrink table - Use info[#info] to get the leaf node name, info[#info-1] for the parent

local basepath = ArkInventory.Options.Internal
local path = basepath

local anchorpoints = {
	[ArkInventory.Const.Anchor.TopRight] = ArkInventory.Localise["TOPRIGHT"],
	[ArkInventory.Const.Anchor.BottomRight] = ArkInventory.Localise["BOTTOMRIGHT"],
	[ArkInventory.Const.Anchor.BottomLeft] = ArkInventory.Localise["BOTTOMLEFT"],
	[ArkInventory.Const.Anchor.TopLeft] = ArkInventory.Localise["TOPLEFT"],
}

function ArkInventory.OptionsInit( )

	local cp = ArkInventory.Global.Me
	local player_id = cp.info.player_id
	
	ArkInventory.Options.Blizzard.args = {
		version = {
			order = 100,
			name = ArkInventory.Global.Version,
			type = "description",
		},
		notes = {
			order = 200,
			name = function( )
				local t = GetAddOnMetadata( ArkInventory.Const.Program.Name, "Notes-" .. GetLocale( ) ) or ""
				if t == "" then
					t = GetAddOnMetadata( ArkInventory.Const.Program.Name, "Notes" ) or ""
				end
				return t or ""
			end,
			type = "description",
		},
		config = {
			order = 300,
			name = ArkInventory.Localise["CONFIG"],
			desc = ArkInventory.Localise["CONFIG_TEXT"],
			type = "execute",
			func = function( )
				ArkInventory.Lib.Dialog:Open( ArkInventory.Const.Frame.Options.Internal )
			end,
		},
		enabled = {
			order = 400,
			name = ArkInventory.Localise["ENABLED"],
			type = "toggle",
			get = function( info )
				return ArkInventory:IsEnabled( )
			end,
			set = function( info, v )
				if v then
					ArkInventory:Enable( )
				else
					ArkInventory:Disable( )
				end
			end,
		},
		debug = {
			order = 500,
			name = ArkInventory.Localise["CONFIG_DEBUG"],
			type = "toggle",
			get = function( info )
				return ArkInventory.Const.Debug
			end,
			set = function( info, v )
				ArkInventory.OutputDebugModeSet( not ArkInventory.Const.Debug )
			end,
		},
	}
	
	path.args = {
		
		version = {
			cmdHidden = true,
			order = 100,
			name = ArkInventory.Global.Version,
			type = "description",
		},
		
		notes = {
			cmdHidden = true,
			order = 200,
			name = function( ) 
				local t = GetAddOnMetadata( ArkInventory.Const.Program.Name, "Notes-" .. GetLocale( ) ) or ""
				if t == "" then
					t = GetAddOnMetadata( ArkInventory.Const.Program.Name, "Notes" ) or ""
				end
				return t or ""
			end,
			type = "description",
		},
		
		system = {
			cmdHidden = true,
			order = 300,
			name = ArkInventory.Localise["CONFIG_SYSTEM"],
			desc = ArkInventory.Localise["CONFIG_SYSTEM_TEXT"],
			type = "group",
			args = {
				font = {
					order = 100,
					name = ArkInventory.Localise["FONT"],
					desc = ArkInventory.Localise["CONFIG_SYSTEM_FONT_TEXT"],
					type = "select",
					dialogControl = "LSM30_Font",
					values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.FONT ),
					get = function( info )
						return ArkInventory.db.profile.option.font.name or ArkInventory.Const.Font.Face
					end,
					set = function( info, v )
						ArkInventory.db.profile.option.font.name = v
						ArkInventory.SetFontAll( )
					end,
				},
				tooltip = {
					order = 200,
					name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP"],
					type = "group",
					--inline = true,
					args = {
						basic = {
							order = 100,
							name = ArkInventory.Localise["GENERAL"],
							type = "group",
							inline = true,
							args = {
								show = {
									order = 100,
									name = ArkInventory.Localise["ENABLED"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ENABLE_TEXT"],
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.tooltip.show
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.show = v
									end,
								},
								paint = {
									order = 200,
									name = ArkInventory.Localise["COLOUR"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_CLASSCOLOUR_TEXT"],
									type = "toggle",
									hidden = function( info )
										return not ArkInventory.db.global.option.tooltip.show
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.colour.class
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.colour.class = v
										ArkInventory.Global.Cache.ItemCount = { }
									end,
								},
								empty = {
									order = 300,
									name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_EMPTY_ADD"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_EMPTY_ADD_TEXT"],
									type = "toggle",
									hidden = function( info )
										return not ArkInventory.db.global.option.tooltip.show
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.add.empty
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.add.empty = v
									end,
								},
								me = {
									order = 400,
									name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_SELF_ONLY"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_SELF_ONLY_TEXT"],
									type = "toggle",
									hidden = function( )
										--return not ArkInventory.db.global.option.tooltip.add.count
										return not ArkInventory.db.global.option.tooltip.show
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.me
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.me = v
										ArkInventory.Global.Cache.ItemCount = { }
									end,
								},
								faction = {
									order = 500,
									name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_FACTION_ONLY"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_FACTION_ONLY_TEXT"],
									type = "toggle",
									hidden = function( )
										--return not ArkInventory.db.global.option.tooltip.add.count or ArkInventory.db.global.option.tooltip.me
										return not ArkInventory.db.global.option.tooltip.show or ArkInventory.db.global.option.tooltip.me
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.faction
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.faction = v
										ArkInventory.Global.Cache.ItemCount = { }
									end,
								},
								vault = {
									order = 600,
									name = ArkInventory.Global.Location[ArkInventory.Const.Location.Vault].Name,
									desc = string.format( ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_VAULT_TEXT"], ArkInventory.Global.Location[ArkInventory.Const.Location.Vault].Name ),
									type = "toggle",
									hidden = function( )
										return not ArkInventory.db.global.option.tooltip.show or ArkInventory.db.global.option.tooltip.me
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.add.vault
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.add.vault = v
										ArkInventory.Global.Cache.ItemCount = { }
									end,
								},
							},
						},
						scale = {
							order = 200,
							name = ArkInventory.Localise["SCALE"],
							type = "group",
							inline = true,
							hidden = function( info )
								return not ArkInventory.db.global.option.tooltip.show
							end,
							args = {
								enabled = {
									order = 100,
									name = ArkInventory.Localise["ENABLED"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_SCALE_TEXT"],
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.tooltip.scale.enabled
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.scale.enabled = v
										for _, obj in pairs( ArkInventory.Global.Tooltip.WOW ) do
											if v then
												obj:SetScale( ArkInventory.db.global.option.tooltip.scale.amount or 1 )
											else
												obj:SetScale( 1 )
											end
										end
									end,
								},
								value = {
									order = 200,
									name = ArkInventory.Localise["SCALE"],
									type = "range",
									min = 0.5,
									max = 2,
									hidden = function( )
										return not ArkInventory.db.global.option.tooltip.scale.enabled
									end,
									step = 0.05,
									isPercent = true,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.scale.amount
									end,
									set = function( info, v )
										local v = math.floor( v / 0.05 ) * 0.05
										if v < 0.5 then v = 0.5 end
										if v > 2 then v = 2 end
										if ArkInventory.db.global.option.tooltip.scale.amount ~= v then
											ArkInventory.db.global.option.tooltip.scale.amount = v
											for _, obj in pairs( ArkInventory.Global.Tooltip.WOW ) do
												obj:SetScale( ArkInventory.db.global.option.tooltip.scale.amount or 1 )
											end
										end
									end,
								},
							},
						},
						count = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ITEMCOUNT_ADD"],
							type = "group",
							inline = true,
							hidden = function( info )
								return not ArkInventory.db.global.option.tooltip.show
							end,
							args = {
								enabled = {
									order = 100,
									name = ArkInventory.Localise["ENABLED"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ITEMCOUNT_ADD_TEXT"],
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.tooltip.add.count
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.add.count = v
									end,
								},
								colour = {
									order = 200,
									name = ArkInventory.Localise["COLOUR"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ITEMCOUNT_COLOUR_TEXT"],
									type = "color",
									hasAlpha = false,
									hidden = function( )
										return not ArkInventory.db.global.option.tooltip.add.count
									end,
									get = function( info )
										local r = ArkInventory.db.global.option.tooltip.colour.count.r
										local g = ArkInventory.db.global.option.tooltip.colour.count.g
										local b = ArkInventory.db.global.option.tooltip.colour.count.b
										return r, g, b
									end,
									set = function( info, r, g, b )
										ArkInventory.db.global.option.tooltip.colour.count.r = r
										ArkInventory.db.global.option.tooltip.colour.count.g = g
										ArkInventory.db.global.option.tooltip.colour.count.b = b
									end,
								},
								showtabs = {
									order = 600,
									name = ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ITEMCOUNT_VAULT_TABS"],
									desc = string.format( ArkInventory.Localise["CONFIG_SYSTEM_TOOLTIP_ITEMCOUNT_VAULT_TABS_TEXT"], ArkInventory.Global.Location[ArkInventory.Const.Location.Vault].Name ),
									type = "toggle",
									hidden = function( )
										return not ArkInventory.db.global.option.tooltip.add.count or ArkInventory.db.global.option.tooltip.me or not ArkInventory.db.global.option.tooltip.add.vault
									end,
									get = function( info )
										return ArkInventory.db.global.option.tooltip.add.tabs
									end,
									set = function( info, v )
										ArkInventory.db.global.option.tooltip.add.tabs = v
										ArkInventory.Global.Cache.ItemCount = { }
									end,
								},
							},
						},
					},
				},
				bugfix = {
					order = 300,
					name = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX"],
					type = "group",
					--inline = true,
					args = {
						framelevel = {
							name = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL"],
							type = "group",
							inline = true,
							args = {
								desc = {
									order = 100,
									name = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_TEXT"],
									type = "description",
								},
								enabled = {
									order = 200,
									name = ArkInventory.Localise["ENABLED"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_TEXT"],
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.bugfix.enable
									end,
									set = function( info, v )
										ArkInventory.db.global.option.bugfix.enable = v
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Init )
									end,
								},
								alert = {
									order = 300,
									name = ArkInventory.Localise["ALERT"],
									desc = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT_TEXT"],
									type = "select",
									hidden = function( )
										return not ArkInventory.db.global.option.bugfix.enable
									end,
									values = function( )
										local t = { }
										t[0] = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT_STYLE0"]
										t[1] = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT_STYLE1"]
										t[2] = ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT_STYLE2"]
										return t
									end,
									get = function( info )
										return ArkInventory.db.global.option.bugfix.alert or 0
									end,
									set = function( info, v )
										ArkInventory.db.global.option.bugfix.alert = v
										ArkInventory.Output( ArkInventory.Localise["CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT"], " = ", ArkInventory.Localise[string.format("CONFIG_SYSTEM_BUGFIX_FRAMELEVEL_ALERT_STYLE%s", v)] )
									end,
								},
							},
						},
					},
				},
				bucket = {
					cmdHidden = true,
					order = 900,
					name = "update timers",
					desc = "description for update timers",
					type = "group",
					--inline = true,
					args = {
						bag = {
							order = 100,
							name = ArkInventory.Localise["LOCATION_BAG"],
							type = "group",
							inline = true,
							args = {
								enabled = {
									order = 100,
									name = "customise",
									desc = "use a custom value for the bag update timer",
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag]
									end,
									set = function( info, v )
										if not v then
											ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag] = nil
										else
											ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag] = 0.5
										end
									end,
								},
								value = {
									order = 200,
									name = "seconds",
									type = "range",
									min = 0.1,
									max = 2,
									hidden = function( )
										return not ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag]
									end,
									step = 0.05,
									get = function( info )
										return ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag] or 0.5
									end,
									set = function( info, v )
										local v = math.floor( v / 0.05 ) * 0.05
										if v < 0.1 then v = 0.1 end
										if v > 2 then v = 2 end
										ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Bag] = v
									end,
								},
							},
						},
						vault = {
							order = 200,
							name = "vault",
							type = "group",
							inline = true,
							args = {
								enabled = {
									order = 100,
									name = "customise",
									desc = "use a custom value for the vault update timer",
									type = "toggle",
									get = function( info )
										return ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault]
									end,
									set = function( info, v )
										if not v then
											ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault] = nil
										else
											ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault] = 1.5
										end
									end,
								},
								value = {
									order = 200,
									name = "seconds",
									type = "range",
									min = 0.1,
									max = 4,
									hidden = function( )
										return not ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault]
									end,
									step = 0.05,
									get = function( info )
										return ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault] or 1.5
									end,
									set = function( info, v )
										local v = math.floor( v / 0.05 ) * 0.05
										if v < 0.1 then v = 0.1 end
										if v > 4 then v = 4 end
										ArkInventory.db.global.option.bucket[ArkInventory.Const.Location.Vault] = v
									end,
								},
							},
						},
					},
				},
			},
		},
		
		auto = {
			cmdHidden = true,
			order = 400,
			name = ArkInventory.Localise["CONFIG_AUTO"],
			type = "group",
			args = {
				auto_open = {
					order = 100,
					type = "group",
					inline = true,
					name = ArkInventory.Localise["OPEN"],
					args = {
						bank = {
							order = 100,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_BANK"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_BANK"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.bank
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.bank = v
							end,
						},
						vault = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_VAULT"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_VAULT"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.vault
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.vault = v
							end,
						},
						mail = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_MAIL"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_MAIL"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.mail
								--return true
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.mail = v
							end,
						},
						merchant = {
							order = 400,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_MERCHANT"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_MERCHANT"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.merchant
								--return true
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.merchant = v
							end,
						},
						trade = {
							order = 500,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_TRADE"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_TRADE"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.trade
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.trade = v
							end,
						},
						auction = {
							order = 600,
							name = ArkInventory.Localise["CONFIG_AUTO_OPEN_AUCTION"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_OPEN"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_OPEN_AUCTION"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.open.auction
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.open.auction = v
							end,
						},
					},
				},
				auto_close = {
					order = 200,
					type = "group",
					inline = true,
					name = ArkInventory.Localise["CLOSE"],
					args = {
						bank = {
							order = 100,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_BANK"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_BANK"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.bank
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.bank = v
							end,
						},
						vault = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_VAULT"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_VAULT"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.vault
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.vault = v
							end,
						},
						mail = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_MAIL"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_MAIL"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.mail
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.mail = v
							end,
						},
						merchant = {
							order = 400,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_MERCHANT"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_MERCHANT"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.merchant
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.merchant = v
							end,
						},
						trade = {
							order = 500,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_TRADE"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_TRADE"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.trade
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.trade = v
							end,
						},
						auction = {
							order = 600,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_AUCTION"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_AUCTION"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.auction
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.auction = v
							end,
						},
						combat = {
							order = 700,
							name = ArkInventory.Localise["CONFIG_AUTO_CLOSE_COMBAT"],
							desc = string.format( ArkInventory.Localise["CONFIG_AUTO_CLOSE"], ArkInventory.Const.Program.Name, ArkInventory.Localise["LOCATION_BAG"], ArkInventory.Localise["CONFIG_AUTO_CLOSE_COMBAT"] ), 
							type = "toggle",
							get = function( info )
								return ArkInventory.db.global.option.auto.close.combat
							end,
							set = function( info, v )
								ArkInventory.db.global.option.auto.close.combat = v
							end,
						},
					},
				},
			},
		},
		
		sorting = {
			cmdHidden = true,
			order = 500,
			name = ArkInventory.Localise["CONFIG_SORTMETHOD"],
			type = "group",
			childGroups = "tab",
			args = { },
		},
		
		settings = {
			cmdHidden = true,
			order = 600,
			name = ArkInventory.Localise["CONFIG_SETTINGS"],
			type = "group",
			childGroups = "tab",
			args = { }, -- computed
		},
		
		control = {
			cmdHidden = true,
			order = 700,
			name = ArkInventory.Localise["CONFIG_CONTROL"],
			type = "group",
			childGroups = "tab",
			args = { }, -- computed 
		},
		
		categories = {
			cmdHidden = true,
			order = 800,
			name = ArkInventory.Localise["CONFIG_CATEGORY"],
			type = "group",
			childGroups = "tab",
			args = { },
		},
		
		search = {
			cmdHidden = true,
			order = 900,
			name = ArkInventory.Localise["CONFIG_SEARCH"],
			type = "group",
			args = {
				scale = {
					order = 100,
					name = ArkInventory.Localise["SCALE"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_SCALE_TEXT"],
					type = "range",
					min = 0.4,
					max = 2,
					step = 0.05,
					isPercent = true,
					get = function( info )
						return ArkInventory.db.profile.option.ui.search.scale
					end,
					set = function( info, v )
						local v = math.floor( v / 0.05 ) * 0.05
						if v < 0.4 then v = 0.4 end
						if v > 2 then v = 2 end
						if ArkInventory.db.profile.option.ui.search.scale ~= v then
							ArkInventory.db.profile.option.ui.search.scale = v
							ArkInventory.Frame_Search_Paint( )
						end
					end,
				},
				background = {
					order = 200,
					name = ArkInventory.Localise["BACKGROUND"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Background",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BACKGROUND ),
							get = function( info )
								return ArkInventory.db.profile.option.ui.search.background.style or ArkInventory.Const.Texture.BackgroundDefault
							end,
							set = function( info, v )
								if ArkInventory.db.profile.option.ui.search.background.style ~= v then
									ArkInventory.db.profile.option.ui.search.background.style = v
									ArkInventory.Frame_Search_Paint( )
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BACKGROUND_COLOUR_TEXT"],
							type = "color",
							hasAlpha = true,
							hidden = function( info )
								return ArkInventory.db.profile.option.ui.search.background.style ~= ArkInventory.Const.Texture.BackgroundDefault
							end,
							get = function( info )
								return ArkInventory.db.profile.option.ui.search.background.colour.r, ArkInventory.db.profile.option.ui.search.background.colour.g, ArkInventory.db.profile.option.ui.search.background.colour.b, ArkInventory.db.profile.option.ui.search.background.colour.a
							end,
							set = function( info, r, g, b, a )
								ArkInventory.db.profile.option.ui.search.background.colour.r = r
								ArkInventory.db.profile.option.ui.search.background.colour.g = g
								ArkInventory.db.profile.option.ui.search.background.colour.b = b
								ArkInventory.db.profile.option.ui.search.background.colour.a = a
								ArkInventory.Frame_Search_Paint( )
							end,
						},
					},
				},
				border = {
					order = 300,
					name = ArkInventory.Localise["BORDER"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Border",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BORDER ),
--[[
							values = function( )
								local t = { }
								for _, v in pairs( ArkInventory.Lib.SharedMedia:List( ArkInventory.Lib.SharedMedia.MediaType.BORDER ) ) do
									t[v] = v
								end
								return t
							end,
]]--
							get = function( info )
								return ArkInventory.db.profile.option.ui.search.border.style or ArkInventory.Const.Texture.BorderDefault
							end,
							set = function( info, v )
								if ArkInventory.db.profile.option.ui.search.border.style ~= v then
									
									ArkInventory.db.profile.option.ui.search.border.style = v
									
									local sd = ArkInventory.Const.Texture.Border[v] or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault]
									ArkInventory.db.profile.option.ui.search.border.size = sd.size
									ArkInventory.db.profile.option.ui.search.border.offset = sd.offset
									ArkInventory.db.profile.option.ui.search.border.scale = sd.scale
									
									ArkInventory.Frame_Search_Paint( )
									
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_COLOUR_TEXT"],
							type = "color",
							hidden = function( )
								return ArkInventory.db.profile.option.ui.search.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							hasAlpha = false,
							get = function( info )
								return ArkInventory.db.profile.option.ui.search.border.colour.r, ArkInventory.db.profile.option.ui.search.border.colour.g, ArkInventory.db.profile.option.ui.search.border.colour.b
							end,
							set = function( info, r, g, b )
								ArkInventory.db.profile.option.ui.search.border.colour.r = r
								ArkInventory.db.profile.option.ui.search.border.colour.g = g
								ArkInventory.db.profile.option.ui.search.border.colour.b = b
								ArkInventory.Frame_Search_Paint( )
							end,
						},
						size = {
							order = 300,
							name = ArkInventory.Localise["HEIGHT"],
							type = "input",
							hidden = function( )
								 return ArkInventory.db.profile.option.ui.search.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								return string.format( "%i", ArkInventory.db.profile.option.ui.search.border.size or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].size )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.db.profile.option.ui.search.border.size ~= v then
									ArkInventory.db.profile.option.ui.search.border.size = v
									ArkInventory.Frame_Search_Paint( )
								end
							end,
						},
						offset = {
							order = 400,
							name = ArkInventory.Localise["OFFSET"],
							type = "input",
							hidden = function( info )
								return ArkInventory.db.profile.option.ui.search.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								return string.format( "%i", ArkInventory.db.profile.option.ui.search.border.offset or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].offset  )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.db.profile.option.ui.search.border.offset ~= v then
									ArkInventory.db.profile.option.ui.search.border.offset = v
									ArkInventory.Frame_Search_Paint( )
								end
							end,
						},
						scale = {
							order = 500,
							name = ArkInventory.Localise["SCALE"],
							desc = ArkInventory.Localise["BORDER_SCALE_TEXT"],
							type = "range",
							hidden = function( )
								return ArkInventory.db.profile.option.ui.search.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							min = 0.25,
							max = 4,
							step = 0.05,
							get = function( info )
								return ArkInventory.db.profile.option.ui.search.border.scale or 1
							end,
							set = function( info, v )
								local v = math.floor( v / 0.05 ) * 0.05
								if v < 0.25 then v = 0.25 end
								if v > 4 then v = 4 end
								if ArkInventory.db.profile.option.ui.search.border.scale ~= v then
									ArkInventory.db.profile.option.ui.search.border.scale = v
									ArkInventory.Frame_Search_Paint( )
								end
							end,
						},
					},
				},
			},
		},
		
		rules = {
			cmdHidden = true,
			order = 1000,
			name = ArkInventory.Localise["CONFIG_RULES"],
			type = "group",
			args = {
				scale = {
					order = 100,
					name = ArkInventory.Localise["SCALE"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_SCALE_TEXT"],
					type = "range",
					min = 0.4,
					max = 2,
					step = 0.05,
					isPercent = true,
					get = function( info )
						return ArkInventory.db.profile.option.ui.rules.scale
					end,
					set = function( info, v )
						local v = math.floor( v / 0.05 ) * 0.05
						if v < 0.4 then v = 0.4 end
						if v > 2 then v = 2 end
						if ArkInventory.db.profile.option.ui.rules.scale ~= v then
							ArkInventory.db.profile.option.ui.rules.scale = v
							ArkInventory.Frame_Rules_Paint( )
						end
					end,
				},
				background = {
					order = 200,
					name = ArkInventory.Localise["BACKGROUND"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["BACKGROUND"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Background",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BACKGROUND ),
							get = function( info )
								return ArkInventory.db.profile.option.ui.rules.background.style or ArkInventory.Const.Texture.BackgroundDefault
							end,
							set = function( info, v )
								if ArkInventory.db.profile.option.ui.rules.background.style ~= v then
									ArkInventory.db.profile.option.ui.rules.background.style = v
									ArkInventory.Frame_Rules_Paint( )
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BACKGROUND_COLOUR_TEXT"],
							type = "color",
							hasAlpha = true,
							hidden = function( info )
								return ArkInventory.db.profile.option.ui.rules.background.style ~= ArkInventory.Const.Texture.BackgroundDefault
							end,
							get = function( info )
								return ArkInventory.db.profile.option.ui.rules.background.colour.r, ArkInventory.db.profile.option.ui.rules.background.colour.g, ArkInventory.db.profile.option.ui.rules.background.colour.b, ArkInventory.db.profile.option.ui.rules.background.colour.a
							end,
							set = function( info, r, g, b, a )
								ArkInventory.db.profile.option.ui.rules.background.colour.r = r
								ArkInventory.db.profile.option.ui.rules.background.colour.g = g
								ArkInventory.db.profile.option.ui.rules.background.colour.b = b
								ArkInventory.db.profile.option.ui.rules.background.colour.a = a
								ArkInventory.Frame_Rules_Paint( )
							end,
						},
					},
				},
				border = {
					order = 300,
					name = ArkInventory.Localise["BORDER"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Border",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BORDER ),
							get = function( info )
								return ArkInventory.db.profile.option.ui.rules.border.style or ArkInventory.Const.Texture.BorderDefault
							end,
							set = function( info, v )
								if v ~= ArkInventory.db.profile.option.ui.rules.border.style then
									
									ArkInventory.db.profile.option.ui.rules.border.style = v
									
									local sd = ArkInventory.Const.Texture.Border[v] or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault]
									ArkInventory.db.profile.option.ui.rules.border.size = sd.size
									ArkInventory.db.profile.option.ui.rules.border.offset = sd.offset
									ArkInventory.db.profile.option.ui.rules.border.scale = sd.scale

									ArkInventory.Frame_Rules_Paint( )
									
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_COLOUR_TEXT"],
							type = "color",
							hidden = function( )
								return ArkInventory.db.profile.option.ui.rules.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							hasAlpha = false,
							get = function( info )
								return ArkInventory.db.profile.option.ui.rules.border.colour.r, ArkInventory.db.profile.option.ui.rules.border.colour.g, ArkInventory.db.profile.option.ui.rules.border.colour.b
							end,
							set = function( info, r, g, b )
								ArkInventory.db.profile.option.ui.rules.border.colour.r = r
								ArkInventory.db.profile.option.ui.rules.border.colour.g = g
								ArkInventory.db.profile.option.ui.rules.border.colour.b = b
								ArkInventory.Frame_Rules_Paint( )
							end,
						},
						size = {
							order = 300,
							name = ArkInventory.Localise["HEIGHT"],
							type = "input",
							hidden = function( )
								return ArkInventory.db.profile.option.ui.rules.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								return string.format( "%i", ArkInventory.db.profile.option.ui.rules.border.size or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].size )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.db.profile.option.ui.rules.border.size ~= v then
									ArkInventory.db.profile.option.ui.rules.border.size = v
									ArkInventory.Frame_Rules_Paint( )
								end
							end,
						},
						offset = {
							order = 400,
							name = ArkInventory.Localise["OFFSET"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.db.profile.option.ui.rules.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.db.profile.option.ui.rules.border.offset or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].offset  )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.db.profile.option.ui.rules.border.offset ~= v then
									ArkInventory.db.profile.option.ui.rules.border.offset = v
									ArkInventory.Frame_Rules_Paint( )
								end
							end,
						},
						scale = {
							order = 500,
							name = ArkInventory.Localise["SCALE"],
							desc = ArkInventory.Localise["BORDER_SCALE_TEXT"],
							type = "range",
							hidden = function( )
								return ArkInventory.db.profile.option.ui.rules.border.style == ArkInventory.Const.Texture.BorderNone
							end,
							min = 0.25,
							max = 4,
							step = 0.05,
							get = function( info )
								return ArkInventory.db.profile.option.ui.rules.border.scale or 1
							end,
							set = function( info, v )
								local v = math.floor( v / 0.05 ) * 0.05
								if v < 0.25 then v = 0.25 end
								if v > 4 then v = 4 end
								if ArkInventory.db.profile.option.ui.rules.border.scale ~= v then
									ArkInventory.db.profile.option.ui.rules.border.scale = v
									ArkInventory.Frame_Rules_Paint( )
								end
							end,
						},
					},
				},
			},
		},
		
		enabled = {
			cmdHidden = true,
			order = 1100,
			name = ArkInventory.Localise["ENABLED"],
			type = "toggle",
			get = function( info )
				return ArkInventory:IsEnabled( )
			end,
			set = function( info, v )
				if v then
					ArkInventory:Enable( )
				else
					ArkInventory:Disable( )
				end
			end,
		},
		
		debug = {
			cmdHidden = true,
			order = 1200,
			name = ArkInventory.Localise["CONFIG_DEBUG"],
			type = "toggle",
			get = function( info )
				return ArkInventory.Const.Debug
			end,
			set = function( info, v )
				ArkInventory.OutputDebugModeSet( not ArkInventory.Const.Debug )
			end,
		},
		
		profiles = LibStub( "AceDBOptions-3.0" ):GetOptionsTable( ArkInventory.db ),
		
	}
	
	path.args.profiles.order = 1100
	
	
	local settingsargs = {
		monitor = {
			order = 100,
			type = "toggle",
			name = ArkInventory.Localise["CONFIG_CONTROL_MONITOR"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_MONITOR_TEXT"], ArkInventory.Global.Location[loc_id].Name, cp.info.name )
			end,
			disabled = function( info )
				local loc_id = tonumber( info[#info-1] )
				return not ArkInventory.Global.Location[loc_id].canPurge
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.realm.player.data[player_id].monitor[loc_id]
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.db.realm.player.data[player_id].monitor[loc_id] = v
			end,
		},
		save = {
			order = 200,
			type = "toggle",
			name = ArkInventory.Localise["CONFIG_CONTROL_SAVE"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_SAVE_TEXT"], ArkInventory.Global.Location[loc_id].Name, cp.info.name )
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.realm.player.data[player_id].save[loc_id]
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.db.realm.player.data[player_id].save[loc_id] = v
			end,
		},
		notifyerase = {
			order = 300,
			type = "toggle",
			name = ArkInventory.Localise["CONFIG_CONTROL_NOTIFY_ERASE"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_NOTIFY_ERASE_TEXT"], ArkInventory.Global.Location[loc_id].Name )
			end,
			disabled = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.realm.player.data[player_id].save[loc_id]
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.profile.option.location[loc_id].notifyerase
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.db.profile.option.location[loc_id].notifyerase = v
			end,
		},
		override = {
			order = 400,
			type = "toggle",
			name = ArkInventory.Localise["CONFIG_CONTROL_OVERRIDE"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_OVERRIDE_TEXT"], ArkInventory.Const.Program.Name, ArkInventory.Global.Location[loc_id].Name )
			end,
			disabled = function( info )
				local loc_id = tonumber( info[#info-1] )
				return not ArkInventory.Global.Location[loc_id].canOverride
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.realm.player.data[player_id].control[loc_id]
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.LocationControlSet( loc_id, v )
			end,
		},
		anchor = {
			order = 500,
			name = ArkInventory.Localise["ANCHOR"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["ANCHOR_TEXT1"], ArkInventory.Global.Location[loc_id].Name )
			end,
			type = "select",
			values = function( )
				return anchorpoints
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.LocationOptionGet( loc_id, { "anchor", loc_id, "point" } )
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				if ArkInventory.LocationOptionGet( loc_id, { "anchor", loc_id, "point" } ) ~= v then
					ArkInventory.LocationOptionSet( loc_id, { "anchor", loc_id, "point" }, v )
					ArkInventory.Frame_Main_Anchor_Set( loc_id )
				end
			end,
		},
		locked = {
			order = 600,
			type = "toggle",
			name = ArkInventory.Localise["LOCK"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_ANCHOR_LOCK_TEXT"], ArkInventory.Global.Location[loc_id].Name )
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.LocationOptionGet( loc_id, { "anchor", loc_id, "locked" } )
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.LocationOptionSet( loc_id, { "anchor", loc_id, "locked" }, v )
				ArkInventory.Frame_Main_Anchor_Set( loc_id )
			end,
		},
		settings = {
			order = 700,
			type = "select",
			name = ArkInventory.Localise["CONFIG_SETTINGS"],
			desc = function( info )
				local loc_id = tonumber( info[#info-1] )
				return string.format( ArkInventory.Localise["CONFIG_CONTROL_SETTINGS_TEXT"], ArkInventory.Global.Location[loc_id].Name )
			end,
			values = function( )
				local t = { }
				for loc_id, loc_data in ipairs( ArkInventory.Global.Location ) do
					if ArkInventory.Global.Location[loc_id].canView then
						t[loc_id] = loc_data.Name
					end
				end
				return t
			end,
			get = function( info )
				local loc_id = tonumber( info[#info-1] )
				return ArkInventory.db.profile.option.use[loc_id]
			end,
			set = function( info, v )
				local loc_id = tonumber( info[#info-1] )
				ArkInventory.db.profile.option.use[loc_id] = v
				ArkInventory.Frame_Main_Generate( loc_id, ArkInventory.Const.Window.Draw.Init )
			end,
		},
	}
	
	path = basepath.args.control.args
	for id, data in pairs( ArkInventory.Global.Location ) do
		path[string.format( "%i", id )] = {
			cmdHidden = true,
			order = id,
			type = "group",
			name = data.Name,
			args = settingsargs,
		}
	end
	
	ArkInventory.OptionsInitSettings( )
	
	ArkInventory.OptionsInitSorting( )
	
	ArkInventory.OptionsInitCategory( )

--[[
	path = basepath.args.system.args
	for k, v in pairs( ArkInventory.Const.Actions ) do

		path[ArkInventory.OptionsSanitiseName( v.Name )] = {
			order = k,
			type = "execute",
			name = v.Name,
			func = v.Scripts.OnClick,
		}
		
	end
]]--
	
	-- slash commands
	basepath.args.config = {
		guiHidden = true,
		order = 9000,
		name = ArkInventory.Localise["CONFIG"],
		desc = ArkInventory.Localise["CONFIG_TEXT"],
		type = "execute",
		func = function( )
			ArkInventory.Lib.Dialog:Open( ArkInventory.Const.Frame.Options.Internal )
		end,
	}
	
	basepath.args.restack = {
		guiHidden = true,
		order = 9000,
		type = "execute",
		name = ArkInventory.Localise["RESTACK"],
		desc = ArkInventory.Localise["RESTACK_TEXT"],
		func = function( )
			ArkInventory.Restack( )
		end,
	}

	basepath.args.cache = {
		guiHidden = true,
		order = 9000,
		name = ArkInventory.Localise["SLASH_CACHE"],
		desc = ArkInventory.Localise["SLASH_CACHE_TEXT"],
		type = "group",
		args = {
			erase = {
				name = ArkInventory.Localise["SLASH_CACHE_ERASE"],
				desc = ArkInventory.Localise["SLASH_CACHE_ERASE_TEXT"],
				type = "group",
				args = {
					confirm = {
						name = ArkInventory.Localise["SLASH_CACHE_ERASE_CONFIRM"],
						desc = ArkInventory.Localise["SLASH_CACHE_ERASE_CONFIRM_TEXT"],
						type = "execute",
						func = function( )
							ArkInventory.EraseSavedData( )
						end,
					},
				},
			},
		},
	}

	basepath.args.db = {
		guiHidden = true,
		order = 9000,
		name = ArkInventory.Localise["SLASH_DB"],
		desc = ArkInventory.Localise["SLASH_DB_TEXT"],
		type = "group",
		args = {
			reset = {
				name = ArkInventory.Localise["SLASH_DB_RESET"],
				desc = ArkInventory.Localise["SLASH_DB_RESET_TEXT"],
				type = "group",
				args = {
					confirm = {
						name = ArkInventory.Localise["SLASH_DB_RESET_CONFIRM"],
						desc = ArkInventory.Localise["SLASH_DB_RESET_CONFIRM_TEXT"],
						type = "execute",
						func = function( )
							ArkInventory.DatabaseReset( )
						end,
					},
				},
			},
		},
	}

end
 
function ArkInventory.OptionsInitSettings( )
	
	local args = {
		
		window = {
			order = 100,
			name = ArkInventory.Localise["CONFIG_SETTINGS_FRAME"],
			type = "group",
			args = {
				hide = {
					order = 100,
					name = ArkInventory.Localise["HIDE"],
					type = "group",
					--inline = true,
					args = {
						title = {
							order = 100,
							type = "toggle",
							name = ArkInventory.Localise["SUBFRAME_NAME_TITLE"],
							desc = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( ArkInventory.Localise["CONFIG_SETTINGS_FRAME_HIDE_TEXT"], ArkInventory.Global.Location[loc_id].Name, ArkInventory.Localise["SUBFRAME_NAME_TITLE"] )
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "framehide", "header" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "framehide", "header" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						search = {
							order = 200,
							type = "toggle",
							name = ArkInventory.Localise["SUBFRAME_NAME_SEARCH"],
							desc = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( ArkInventory.Localise["CONFIG_SETTINGS_FRAME_HIDE_TEXT"], ArkInventory.Global.Location[loc_id].Name, ArkInventory.Localise["SUBFRAME_NAME_SEARCH"] )
							end,
							disabled = function( info )
								local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.Global.Location[loc_id].canSearch
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "framehide", "search" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.Global.Location[loc_id].filter = nil
								ArkInventory.LocationOptionSetReal( loc_id, { "framehide", "search" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						changer = {
							order = 300,
							type = "toggle",
							name = ArkInventory.Localise["SUBFRAME_NAME_BAGCHANGER"],
							desc = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( ArkInventory.Localise["CONFIG_SETTINGS_FRAME_HIDE_TEXT"], ArkInventory.Global.Location[loc_id].Name, ArkInventory.Localise["SUBFRAME_NAME_BAGCHANGER"] )
							end,
							disabled = function( info )
								local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.Global.Location[loc_id].hasChanger
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "framehide", "changer" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "framehide", "changer" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						status = {
							order = 400,
							type = "toggle",
							name = ArkInventory.Localise["SUBFRAME_NAME_STATUS"],
							desc = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( ArkInventory.Localise["CONFIG_SETTINGS_FRAME_HIDE_TEXT"], ArkInventory.Global.Location[loc_id].Name, ArkInventory.Localise["SUBFRAME_NAME_STATUS"] )
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "framehide", "status" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "framehide", "status" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
					},
				},
				scale = {
					order = 200,
					name = ArkInventory.Localise["SCALE"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_SCALE_TEXT"],
					type = "range",
					min = 0.4,
					max = 2,
					step = 0.05,
					isPercent = true,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "window", "scale" } )
					end,
					set = function( info, v )
						local v = math.floor( v / 0.05 ) * 0.05
						if v < 0.4 then v = 0.4 end
						if v > 2 then v = 2 end
						local loc_id = tonumber( info[#info-2] )
						if ArkInventory.LocationOptionGetReal( loc_id, { "window", "scale" } ) ~= v then
							ArkInventory.LocationOptionSetReal( loc_id, { "window", "scale" }, v )
							ArkInventory.Frame_Main_Scale_All( )
						end
					end,
				},
				padding = {
					order = 300,
					name = ArkInventory.Localise["PADDING"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_PADDING_TEXT"],
					type = "range",
					min = 4,
					max = 32,
					step = 1,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "window", "pad" } )
					end,
					set = function( info, v )
						local v = math.floor( v )
						if v < 4 then v = 4 end
						if v > 32 then v = 32 end
						local loc_id = tonumber( info[#info-2] )
						if v ~= ArkInventory.LocationOptionGetReal( loc_id, { "window", "pad" } ) then
							ArkInventory.LocationOptionSetReal( loc_id, { "window", "pad" }, math.floor( v ) )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				width = {
					order = 400,
					name = ArkInventory.Localise["WIDTH"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_WIDTH_TEXT"],
					type = "range",
					min = 6,
					max = 40,
					step = 1,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "window", "width" } )
					end,
					set = function( info, v )
						local v = math.floor( v )
						if v < 6 then v = 6 end
						if v > 40 then v = 40 end
						local loc_id = tonumber( info[#info-2] )
						if v ~= ArkInventory.LocationOptionGetReal( loc_id, { "window", "width" } ) then
							ArkInventory.LocationOptionSetReal( loc_id, { "window", "width" }, v )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				sorting = {
					order = 450,
					name = ArkInventory.Localise["CONFIG_SORTMETHOD_SORT"],
					type = "group",
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SORTMETHOD_STYLE_TEXT"],
							type = "select",
							values = function( )
								local t = { }
								for k, v in pairs( ArkInventory.db.global.option.sort.data ) do
									if v.used then
										local n = string.format( "%s [%04i]", v.name, k )
										if k == 0 then
											n = string.format( "%s (%s)", n, ArkInventory.Localise["DEFAULT"] )
										end
										t[k] = n
									end
								end
								return t
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local v = ArkInventory.LocationOptionGetReal( loc_id, { "sort", "default" } )
								return v
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "sort", "default" }, v )
								ArkInventory.LocationSetValue( nil, "resort", true )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
							end,
						},
						open = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_SETTINGS_SORTING_OPEN"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_SORTING_OPEN_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "sort", "open" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "sort", "open" }, v )
							end,
						},
						instant = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_SETTINGS_SORTING_INSTANT"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_SORTING_INSTANT_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "sort", "instant" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "sort", "instant" }, v )
							end,
						},
					},
				},
				background = {
					order = 500,
					name = ArkInventory.Localise["BACKGROUND"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Background",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BACKGROUND ),
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "style" } ) or ArkInventory.Const.Texture.BackgroundDefault
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "style" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "background", "style" }, v )
									ArkInventory.Frame_Main_Paint_All( )
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["BACKGROUND_COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BACKGROUND_COLOUR_TEXT"],
							type = "color",
							hasAlpha = true,
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "style" } ) ~= ArkInventory.Const.Texture.BackgroundDefault
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "colour", "b" } )
								local a = ArkInventory.LocationOptionGetReal( loc_id, { "window", "background", "colour", "a" } )
								return r, g, b, a
							end,
							set = function( info, r, g, b, a )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "background", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "background", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "background", "colour", "b" }, b )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "background", "colour", "a" }, a )
								ArkInventory.Frame_Main_Paint_All( )
							end,
						},
					},
				},	
				border = {
					order = 600,
					name = ArkInventory.Localise["BORDER"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Border",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BORDER ),
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) or ArkInventory.Const.Texture.BorderDefault
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) ~= v then
									
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "style" }, v )
									
									local sd = ArkInventory.Const.Texture.Border[v] or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault]
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "size" }, sd.size )
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "offset" }, sd.offset )
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "scale" }, sd.scale )

									ArkInventory.Frame_Main_Paint_All( )
									
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_BORDER_COLOUR_TEXT"],
							type = "color",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							hasAlpha = false,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "colour", "b" } )
								return r, g, b
							end,
							set = function( info, r, g, b )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "colour", "b" }, b )
								ArkInventory.Frame_Main_Paint_All( )
							end,
						},
						size = {
							order = 300,
							name = ArkInventory.Localise["HEIGHT"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "size" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].size )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "size" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "size" }, v )
									ArkInventory.Frame_Main_Paint_All( )
								end
							end,
						},
						offset = {
							order = 400,
							name = ArkInventory.Localise["OFFSET"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "offset" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].offset  )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "offset" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "offset" }, v )
									ArkInventory.Frame_Main_Paint_All( )
								end
							end,
						},
						scale = {
							order = 500,
							name = ArkInventory.Localise["SCALE"],
							desc = ArkInventory.Localise["BORDER_SCALE_TEXT"],
							type = "range",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							min = 0.25,
							max = 4,
							step = 0.05,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "scale" } ) or 1
							end,
							set = function( info, v )
								local v = math.floor( v / 0.05 ) * 0.05
								if v < 0.25 then v = 0.25 end
								if v > 4 then v = 4 end
								local loc_id = tonumber( info[#info-3] )
								if v ~= ArkInventory.LocationOptionGetReal( loc_id, { "window", "border", "scale" } ) then
									ArkInventory.LocationOptionSetReal( loc_id, { "window", "border", "scale" }, v )
									ArkInventory.Frame_Main_Paint_All( )
								end
							end,
						},
					},
				},
				changer = {
					order = 700,
					name = ArkInventory.Localise["SUBFRAME_NAME_BAGCHANGER"],
					type = "group",
					--inline = true,
					args = {
						highlight = {
							order = 100,
							name = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_HIGHLIGHT"],
							type = "group",
							inline = true,
							args = {
								show = {
									order = 100,
									name = ArkInventory.Localise["SHOW"],
									desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_HIGHLIGHT_TEXT"],
									type = "toggle",
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "changer", "highlight", "show" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "highlight", "show" }, v )
										ArkInventory.ItemCategoryClear( nil, nil, true )
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									end,
								},
								colour = {
									order = 200,
									name = ArkInventory.Localise["COLOUR"],
									desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_HIGHLIGHT_COLOUR_TEXT"],
									type = "color",
									hasAlpha = false,
									hidden = function( info )
										local loc_id = tonumber( info[#info-4] )
										return not ArkInventory.LocationOptionGetReal( loc_id, { "changer", "highlight", "show" } )
									end,
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										local r = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "highlight", "colour", "r" } )
										local g = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "highlight", "colour", "g" } )
										local b = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "highlight", "colour", "b" } )
									return r, g, b
									end,
									set = function( info, r, g, b )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "highlight", "colour", "r" }, r )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "highlight", "colour", "g" }, g )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "highlight", "colour", "b" }, b )
										ArkInventory.Frame_Main_Paint_All( )
									end,	
								},
							},
						},
						free = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_FREE"],
							type = "group",
							inline = true,
							args = {
								show = {
									order = 100,
									name = ArkInventory.Localise["SHOW"],
									desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_FREE_TEXT"],
									type = "toggle",
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "changer", "freespace", "show" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "freespace", "show" }, v )
										ArkInventory.ItemCategoryClear( nil, nil, true )
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									end,
								},
								colour = {
									order = 200,
									name = ArkInventory.Localise["COLOUR"],
									desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_CHANGER_FREE_COLOUR_TEXT"],
									type = "color",
									hidden = function( info )
										local loc_id = tonumber( info[#info-4] )
										return not ArkInventory.LocationOptionGetReal( loc_id, { "changer", "freespace", "show" } )
									end,
										hasAlpha = false,
										get = function( info )
										local loc_id = tonumber( info[#info-4] )
										local r = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "freespace", "colour", "r" } )
										local g = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "freespace", "colour", "g" } )
										local b = ArkInventory.LocationOptionGetReal( loc_id, { "changer", "freespace", "colour", "b" } )
										return r, g, b
									end,
									set = function( info, r, g, b )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "freespace", "colour", "r" }, r )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "freespace", "colour", "g" }, g )
										ArkInventory.LocationOptionSetReal( loc_id, { "changer", "freespace", "colour", "b" }, b )
										ArkInventory.Frame_Changer_Update( ArkInventory.Const.Location.Bag )
										ArkInventory.Frame_Changer_Update( ArkInventory.Const.Location.Bank )
										ArkInventory.Frame_Changer_Update( ArkInventory.Const.Location.Vault )
									end,
								},
							},
						},
					},
				},
				status = {
					order = 900,
					name = ArkInventory.Localise["SUBFRAME_NAME_STATUS"],
					type = "group",
					--inline = true,
					args = {
						emptytext = {
							order = 100,
							name = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_STATUS_EMPTY"],
							type = "group",
							inline = true,
							args = {
								show = {
									order = 100,
									name = ArkInventory.Localise["SHOW"],
									desc = ArkInventory.Localise["CONFIG_SETTINGS_FRAME_STATUS_EMPTY_TEXT"],
									type = "toggle",
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "show" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										if ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "show" } ) ~= v then
											ArkInventory.LocationOptionSetReal( loc_id, { "status", "emptytext", "show" }, v )
											ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
										end
									end,
								},
								colour = {
									order = 200,
									name = ArkInventory.Localise["LDB_BAGS_COLOUR_USE"],
									desc = ArkInventory.Localise["LDB_BAGS_COLOUR_USE_TEXT"],
									type = "toggle",
									hidden = function( info )
										local loc_id = tonumber( info[#info-4] )
										return not ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "show" } )
									end,
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "colour" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "status", "emptytext", "colour" }, v )
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									end,
								},
								full = {
									order = 300,
									name = ArkInventory.Localise["LDB_BAGS_STYLE"],
									desc = ArkInventory.Localise["LDB_BAGS_STYLE_TEXT"],
									type = "toggle",
									hidden = function( info )
										local loc_id = tonumber( info[#info-4] )
										return not ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "show" } )
									end,
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "full" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "status", "emptytext", "full" }, v )
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									end,
								},
								includetype = {
									order = 400,
									name = ArkInventory.Localise["LDB_BAGS_INCLUDE_TYPE"],
									desc = ArkInventory.Localise["LDB_BAGS_INCLUDE_TYPE_TEXT"],
									type = "toggle",
									hidden = function( info )
										local loc_id = tonumber( info[#info-4] )
										return not ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "show" } )
									end,
									get = function( info )
										local loc_id = tonumber( info[#info-4] )
										return ArkInventory.LocationOptionGetReal( loc_id, { "status", "emptytext", "includetype" } )
									end,
									set = function( info, v )
										local loc_id = tonumber( info[#info-4] )
										ArkInventory.LocationOptionSetReal( loc_id, { "status", "emptytext", "includetype" }, v )
										ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									end,
								},
							},
						},
					},
				},
			},
		},
		
		bars = {
			order = 200,
			name = ArkInventory.Localise["CONFIG_SETTINGS_BARS"],
			type = "group",
			args = {
				anchor = {
					order = 100,
					name = ArkInventory.Localise["ANCHOR"],
					desc = string.format( ArkInventory.Localise["ANCHOR_TEXT2"], ArkInventory.Localise["CONFIG_SETTINGS_BARS"], "" ),
					type = "select",
					values = function( )
						return anchorpoints
					end,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "anchor" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "anchor" } ) ~= v then
							ArkInventory.LocationOptionSetReal( loc_id, { "bar", "anchor" }, v )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				per_bar = {
					order = 200,
					name = ArkInventory.Localise["CONFIG_SETTINGS_BARS_PER_ROW"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_PER_ROW_TEXT"],
					type = "range",
					min = 1,
					max = 16,
					step = 1,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "per" } )
					end,
					set = function( info, v )
						local v = math.floor( v )
						if v < 1 then v = 1 end
						if v > 16 then v = 16 end
						local loc_id = tonumber( info[#info-2] )
						if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "per" } ) ~= v then
							ArkInventory.LocationOptionSetReal( loc_id, { "bar", "per" }, v )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				compact = {
					order = 400,
					name = ArkInventory.Localise["CONFIG_SETTINGS_BARS_COMPACT"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_COMPACT_TEXT"],
					type = "toggle",
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "compact" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						ArkInventory.LocationOptionSetReal( loc_id, { "bar", "compact" }, v )
						ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
					end,
				},
				empty = {
					order = 500,
					name = ArkInventory.Localise["CONFIG_SETTINGS_BARS_SHOW_EMPTY"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_SHOW_EMPTY_TEXT"],
					type = "toggle",
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "showempty" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						ArkInventory.LocationOptionSetReal( loc_id, { "bar", "showempty" }, v )
						ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
					end,
				},
				padding = {
					order= 600,
					name = ArkInventory.Localise["PADDING"],
					type = "group",
					--inline = true,
					args = {
						internal = {
							order = 100,
							name = ArkInventory.Localise["INTERNAL"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_PADDING_INTERNAL_TEXT"],
							type = "range",
							min = 4,
							max = 32,
							step = 1,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "pad", "internal" } )
							end,
							set = function( info, v )
								local v = math.floor( v )
								if v < 4 then v = 4 end
								if v > 32 then v = 32 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "pad", "internal" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "pad", "internal" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
								end
							end,
						},
						external = {
							order = 200,
							name = ArkInventory.Localise["EXTERNAL"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_PADDING_EXTERNAL_TEXT"],
							type = "range",
							min = 0,
							max = 32,
							step = 1,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "pad", "external" } )
							end,
							set = function( info, v )
								local v = math.floor( v )
								if v < 0 then v = 0 end
								if v > 32 then v = 32 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "pad", "external" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "pad", "external" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
								end
							end,
						},
					},
				},
				background = {
					order = 650,
					name = ArkInventory.Localise["BACKGROUND"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							type = "select",
							disabled = true,
							dialogControl = "LSM30_Background",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BACKGROUND ),
							get = function( info )
								return ArkInventory.Const.Texture.BackgroundDefault
							end,
							set = function( info, v )
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_BACKGROUND_TEXT"],
							type = "color",
							hasAlpha = true,
--							hidden = function( info )
--								local loc_id = tonumber( info[#info-3] )
--								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "background", "style" } ) ~= ArkInventory.Const.Texture.BackgroundDefault
--							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "background", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "background", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "background", "colour", "b" } )
								local a = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "background", "colour", "a" } )
								return r, g, b, a
							end,
							set = function( info, r, g, b, a )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "background", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "background", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "background", "colour", "b" }, b )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "background", "colour", "a" }, a )
								ArkInventory.Frame_Main_Paint_All( )
							end,
						},
					},
				},	
				border = {
					order = 700,
					name = ArkInventory.Localise["BORDER"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Border",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BORDER ),
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) or ArkInventory.Const.Texture.BorderDefault
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								if v ~= ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) then
									
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "style" }, v )
									
									local sd = ArkInventory.Const.Texture.Border[v] or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault]
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "size" }, sd.size )
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "offset" }, sd.offset )
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "scale" }, sd.scale )

									ArkInventory.Frame_Bar_Paint_All( )
									
								end
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_BORDER_COLOUR_TEXT"],
							type = "color",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							hasAlpha = false,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "colour", "b" } )
								return r, g, b
							end,
							set = function( info, r, g, b )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "colour", "b" }, b )
								ArkInventory.Frame_Bar_Paint_All( )
							end,
						},
						size = {
							order = 300,
							name = ArkInventory.Localise["HEIGHT"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "size" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].size )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "size" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "size" }, v )
									ArkInventory.Frame_Bar_Paint_All( )
								end
							end,
						},
						offset = {
							order = 400,
							name = ArkInventory.Localise["OFFSET"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "offset" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].offset  )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "offset" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "offset" }, v )
									ArkInventory.Frame_Main_Paint_All( )
								end
							end,
						},
						scale = {
							order = 500,
							name = ArkInventory.Localise["SCALE"],
							type = "range",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							min = 0.25,
							max = 4,
							step = 0.05,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "scale" } ) or 1
							end,
							set = function( info, v )
								local v = math.floor( v / 0.05 ) * 0.05
								if v < 0.25 then v = 0.25 end
								if v > 4 then v = 4 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "border", "scale" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "border", "scale" }, v )
									ArkInventory.Frame_Bar_Paint_All( )
								end
							end,
						},
					},
				},
				label = {
					order = 800,
					name = ArkInventory.Localise["NAME"],
					type = "group",
					--inline = true,
					args = {
						show = {
							order = 100,
							type = "toggle",
							name = ArkInventory.Localise["SHOW"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_NAME_SHOW_TEXT"],
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "show" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "name", "show" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_NAME_COLOUR_TEXT"],
							type = "color",
							hidden = function( info )
							local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "show" } )
							end,
							hasAlpha = false,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "colour", "b" } )
								return r, g, b
							end,
							set = function( info, r, g, b )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "name", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "name", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "bar", "name", "colour", "b" }, b )
								ArkInventory.Frame_Bar_Paint_All( )
							end,
						},
						height = {
							order = 300,
							name = ArkInventory.Localise["HEIGHT"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_BARS_NAME_HEIGHT_TEXT"],
							type = "range",
							min = 4,
							max = 32,
							step = 1,
							hidden = function( info )
							local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "show" } )
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "height" } )
							end,
							set = function( info, v )
								local v = math.floor( v )
								if v < 4 then v = 4 end
								if v > 32 then v = 32 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "bar", "name", "height" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "bar", "name", "height" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
								end
							end,
						},
						
					},
				},
			},
		},
		
		items = {
			order = 300,
			name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS"],
			type = "group",
			args = {
				anchor = {
					order = 100,
					name = ArkInventory.Localise["ANCHOR"],
					desc = string.format( ArkInventory.Localise["ANCHOR_TEXT2"], ArkInventory.Localise["CONFIG_SETTINGS_ITEMS"], "" ),
					type = "select",
					values = function( )
						return anchorpoints
					end,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "anchor" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "anchor" } ) ~= v then
							ArkInventory.LocationOptionSetReal( loc_id, { "slot", "anchor" }, v )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				padding = {
					order = 200,
					name = ArkInventory.Localise["PADDING"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_PADDING_TEXT"],
					type = "range",
					min = 1,
					max = 16,
					step = 1,
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "pad" } )
					end,
					set = function( info, v )
						local v = math.floor( v )
						if v < 1 then v = 1 end
						if v > 16 then v = 16 end
						local loc_id = tonumber( info[#info-2] )
						if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "pad" } ) ~= v then
							ArkInventory.LocationOptionSetReal( loc_id, { "slot", "pad" }, v )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
						end
					end,
				},
				hidden = {
					order = 300,
					name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_HIDDEN"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_HIDDEN_TEXT"],
					type = "toggle",
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "ignorehidden" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						ArkInventory.LocationOptionSetReal( loc_id, { "slot", "ignorehidden" }, v )
						ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
					end,
				},
				fade = {
					order = 400,
					name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_FADE"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_FADE_TEXT"],
					type = "toggle",
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "offline", "fade" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						ArkInventory.LocationOptionSetReal( loc_id, { "slot", "offline", "fade" }, v )
						ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
					end,
				},
				tint = {
					order = 500,
					name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_TINT_USABLE"],
					desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_TINT_USABLE_TEXT"],
					type = "toggle",
					get = function( info )
						local loc_id = tonumber( info[#info-2] )
						return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "unusable", "tint" } )
					end,
					set = function( info, v )
						local loc_id = tonumber( info[#info-2] )
						ArkInventory.LocationOptionSetReal( loc_id, { "slot", "unusable", "tint" }, v )
						ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
					end,
				},
				border = {
					order = 600,
					name = ArkInventory.Localise["BORDER"],
					type = "group",
					--inline = true,
					args = {
						style = {
							order = 100,
							name = ArkInventory.Localise["STYLE"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_BORDER_STYLE_TEXT"],
							type = "select",
							dialogControl = "LSM30_Border",
							values = ArkInventory.Lib.SharedMedia:HashTable( ArkInventory.Lib.SharedMedia.MediaType.BORDER ),
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) or ArkInventory.Const.Texture.BorderDefault
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								if v ~= ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) then
									
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "style" }, v )
									
									local sd = ArkInventory.Const.Texture.Border[v] or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault]
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "size" }, sd.size )
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "offset" }, sd.offset )
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "scale" }, sd.scale )
									
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
									
								end
							end,
						},
						rarity = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_BORDER_RARITY"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_BORDER_RARITY_TEXT"],
							type = "toggle",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "rarity" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "rarity" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						raritycutoff = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_BORDER_RARITY_CUTOFF"],
							desc = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_BORDER_RARITY_CUTOFF_TEXT"], _G[string.format( "ITEM_QUALITY%d_DESC", ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "raritycutoff" } ) or 0 )] )
							end,
							type = "select",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone or not ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "rarity" } )
							end,
							values = function( )
								local t = { }
								for z in pairs( ITEM_QUALITY_COLORS ) do
									if z >= 0 then
										t[tostring( z )] = _G[string.format( "ITEM_QUALITY%d_DESC", z )]
									end
								end
								return t
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return tostring( ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "raritycutoff" } ) or 0 )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "raritycutoff" }, tonumber( v ) )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						size = {
							order = 400,
							name = ArkInventory.Localise["HEIGHT"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "size" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].size )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "size" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "size" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
								end
							end,
						},
						offset = {
							order = 500,
							name = ArkInventory.Localise["OFFSET"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "offset" } ) or ArkInventory.Const.Texture.Border[ArkInventory.Const.Texture.BorderDefault].offset  )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "offset" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "offset" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
								end
							end,
						},
						scale = {
							order = 600,
							name = ArkInventory.Localise["SCALE"],
							type = "range",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "style" } ) == ArkInventory.Const.Texture.BorderNone
							end,
							min = 0.25,
							max = 4,
							step = 0.05,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "scale" } ) or 1
							end,
							set = function( info, v )
								local v = math.floor( v / 0.05 ) * 0.05
								if v < 0.25 then v = 0.25 end
								if v > 4 then v = 4 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "border", "scale" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "border", "scale" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
								end
							end,
						},
					},
				},
				empty = {
					order = 700,
					name = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY"],
					type = "group",
					--inline = true,
					args = {
						icon = {
							order = 100,
							name = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_ICON"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_ICON_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "empty", "icon" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "empty", "icon" }, v )
								ArkInventory.Frame_Item_Empty_Paint_All( )
							end,
						},
						clump = {
							order = 200,
							name = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_CLUMP"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_CLUMP_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "empty", "clump" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "empty", "clump" }, v )
								ArkInventory.ItemCacheClear( )
								ArkInventory.ItemCategoryClear( nil, nil, true )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Recalculate )
							end,
						},
						border = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_BORDER"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_BORDER_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "empty", "border" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "empty", "border" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						colour = {
							order = 400,
							name = ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_COLOUR"],
							type = "group",
							inline = true,
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "empty", "icon" } ) and not ArkInventory.LocationOptionGetReal( loc_id, { "slot", "empty", "border" } )
							end,
							args = { },
						},
					},
				},
				age = {
					order = 900,
					name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE"],
					type = "group",
					--inline = true,
					args = {
						show = {
							order = 100,
							name = ArkInventory.Localise["SHOW"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE_SHOW_TEXT"],
							type = "toggle",
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "show" } )
							end,
							set = function( info, v )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "new", "show" }, v )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						colour = {
							order = 200,
							name = ArkInventory.Localise["COLOUR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE_COLOUR_TEXT"],
							type = "color",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "show" } )
							end,
							hasAlpha = false,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								local r = ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "colour", "r" } )
								local g = ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "colour", "g" } )
								local b = ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "colour", "b" } )
								return r, g, b
							end,
							set = function( info, r, g, b )
								local loc_id = tonumber( info[#info-3] )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "new", "colour", "r" }, r )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "new", "colour", "g" }, g )
								ArkInventory.LocationOptionSetReal( loc_id, { "slot", "new", "colour", "b" }, b )
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
						cutoff = {
							order = 300,
							name = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE_CUTOFF"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE_CUTOFF_TEXT"],
							type = "input",
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "show" } )
							end,
							get = function( info )
								local loc_id = tonumber( info[#info-3] )
								return string.format( "%i", ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "cutoff" } ) )
							end,
							set = function( info, v )
								local v = math.floor( tonumber( v ) or 0 )
								if v < 0 then v = 0 end
								local loc_id = tonumber( info[#info-3] )
								if ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "cutoff" } ) ~= v then
									ArkInventory.LocationOptionSetReal( loc_id, { "slot", "new", "cutoff" }, v )
									ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
								end
							end,
						},
						reset = {
							order = 400,
							name = ArkInventory.Localise["CLEAR"],
							desc = ArkInventory.Localise["CONFIG_SETTINGS_ITEMS_AGE_RESET_TEXT"],
							type = "execute",
							disabled = function( )
								return true
							end,
							hidden = function( info )
								local loc_id = tonumber( info[#info-3] )
								return not ArkInventory.LocationOptionGetReal( loc_id, { "slot", "new", "show" } )
							end,
							func = function( )
								-- reset item ages
								ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Refresh )
							end,
						},
					},
				},
			},
		},
		
	}
	
	-- empty slot options
	for k, v in pairs( ArkInventory.Const.Slot.Data ) do
		if not v.hide then
			args.items.args.empty.args.colour.args[string.format( "%i", k )] = {
				order = 100,
				name = v.long,
				desc = string.format( ArkInventory.Localise["CONFIG_SETTINGS_EMPTY_COLOUR_TEXT"], v.long ),
				type = "color",
				hasAlpha = false,
				hidden = false,
				get = function( info )
					local loc_id = tonumber( info[#info-4] )
					local key = tonumber( info[#info] )
					local r = ArkInventory.LocationOptionGet( loc_id, { "slot", "data", key, "colour", "r" } )
					local g = ArkInventory.LocationOptionGet( loc_id, { "slot", "data", key, "colour", "g" } )
					local b = ArkInventory.LocationOptionGet( loc_id, { "slot", "data", key, "colour", "b" } )
					return r, g, b
				end,
				set = function( info, r, g, b )
					local loc_id = tonumber( info[#info-4] )
					local key = tonumber( info[#info] )
					ArkInventory.LocationOptionSet( loc_id, { "slot", "data", key, "colour", "r" }, r )
					ArkInventory.LocationOptionSet( loc_id, { "slot", "data", key, "colour", "g" }, g )
					ArkInventory.LocationOptionSet( loc_id, { "slot", "data", key, "colour", "b" }, b )
					ArkInventory.Frame_Item_Empty_Paint_All( )
				end,
			}
		end
	end
	
	
	for id, data in pairs( ArkInventory.Global.Location ) do
		
		if data.canView then

			basepath.args.settings.args[string.format( "%i", id )] = {
				cmdHidden = true,
				order = id,
				type = "group",
				name = data.Name,
				args = args,
			}
			
		end
		
	end
	
 end
 
function ArkInventory.OptionsSanitiseName( v )
	local v = string.gsub( ArkInventory.Localise[v] or v, " ", "-" )
	return v
end

function ArkInventory.OptionsInitCategory( )
	
	path = basepath.args.categories.args
	
	path.custom = {
		type = "group",
		name = ArkInventory.Localise["CONFIG_CATEGORY_CUSTOM"],
		args = { }, -- computed
	}
	
	ArkInventory.OptionsInitCategoryCustom( path.custom.args )
	
end

function ArkInventory.OptionsInitCategoryCustom( path )

	path.add = {
		order = 100,
		name = ArkInventory.Localise["CONFIG_CATEGORY_ADD"],
		desc = ArkInventory.Localise["CONFIG_CATEGORY_ADD_TEXT"],
		type = "input",
		get = function( )
			return ""
		end,
		set = function( info, v )
			ArkInventory.CategoryCustomAdd( v )
			--ArkInventory.OptionsInitCategory( )
		end,
	}
	
	path.sortbyname = {
		order = 200,
		name = ArkInventory.Localise["SORT_BY_NAME"],
		type = "execute",
		func = function( )
			ArkInventory.Global.Options.CustomCategorySort = true
			ArkInventory.OptionsInitCategory( )
		end,
	}
	
	path.sortbynumber = {
		order = 200,
		name = ArkInventory.Localise["SORT_BY_NUMBER"],
		type = "execute",
		func = function( )
			ArkInventory.Global.Options.CustomCategorySort = false
			ArkInventory.OptionsInitCategory( )
		end,
	}
	
	path.reload = {
		order = 300,
		name = ArkInventory.Localise["RELOAD"],
		type = "execute",
		func = function( )
			ArkInventory.OptionsInitCategory( )
		end,
	}
	
	for k, cat in pairs( ArkInventory.db.global.option.category[ArkInventory.Const.Category.Type.Custom].data ) do
		
		if cat.used then
			
			local n = ""
			if ArkInventory.Global.Options.CustomCategorySort then
				n = string.format( "%s [%04i]", cat.name, k )
			else
				n = string.format( "[%04i] %s", k, cat.name )
			end
			
			path[string.format( "category%04i", k )] = {
				order = 100,
				name = n,
				type = "group",
				args = {
					ren = { 
						order = 100,
						name = ArkInventory.Localise["RENAME"],
						desc = ArkInventory.Localise["CONFIG_CATEGORY_RENAME_TEXT"],
						type = "input",
						get = function( )
							return cat.name
						end,
						set = function( info, v )
							ArkInventory.CategoryCustomRename( k, v )
							--ArkInventory.OptionsInitCategory( )
						end,
					},
					del = { 
						order = 200,
						name = ArkInventory.Localise["DELETE"],
						desc = ArkInventory.Localise["CONFIG_CATEGORY_DELETE_TEXT"],
						type = "execute",
						func = function( )
							ArkInventory.CategoryCustomDelete( k, "DELETE" )
							--ArkInventory.OptionsInitCategory( )
						end,
					},
				},
			}
			
		end
		
	end
	
end
	
function ArkInventory.OptionsInitSorting( )
	
	path = basepath.args.sorting.args
	
	path.custom = {
		type = "group",
		name = ArkInventory.Localise["CONFIG_SORTMETHOD"],
		args = { }, -- computed
	}
	
	path = path.custom.args
	
	path.add = {
		order = 100,
		name = ArkInventory.Localise["CONFIG_SORTMETHOD_ADD"],
		desc = ArkInventory.Localise["CONFIG_SORTMETHOD_ADD_TEXT"],
		type = "input",
		get = function( )
			return ""
		end,
		set = function( info, v )
			ArkInventory.SortKeyCustomAdd( v )
		end,
	}
	
	path.sortbyname = {
		order = 200,
		name = ArkInventory.Localise["SORT_BY_NAME"],
		type = "execute",
		func = function( )
			ArkInventory.Global.Options.CustomSortKeySort = true
			ArkInventory.OptionsInitSorting( )
		end,
	}
	
	path.sortbynumber = {
		order = 200,
		name = ArkInventory.Localise["SORT_BY_NUMBER"],
		type = "execute",
		func = function( )
			ArkInventory.Global.Options.CustomSortKeySort = false
			ArkInventory.OptionsInitSorting( )
		end,
	}
	
	path.reload = {
		order = 300,
		name = ArkInventory.Localise["RELOAD"],
		type = "execute",
		func = function( )
			ArkInventory.OptionsInitSorting( )
		end,
	}
	
	
	-- sort order options
	local sortorderargs = { }
	for sortkey, active in pairs( ArkInventory.Const.SortKeys ) do
		
		if active then
		
			sortorderargs[sortkey] = {
				
				order = function( info )
					
					local p = 9000
					local id = tonumber( info[#info-2] )
					local t = ArkInventory.db.global.option.sort.data[id].order
					
					for k, v in ipairs( t ) do
						if info[#info] == v then
							p = k * 100
							break
						end
					end
					
					return p
				end,
				name = "",
				type = "group",
				inline = true,
				hidden = false,
				args = {
					enabled = {
						order = 100,
						name = function( info )
							local id = tonumber( info[#info-3] )
							local checked = ArkInventory.db.global.option.sort.data[id].active[info[#info-1]]
							local n = ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_" .. string.upper( info[#info-1] )]
							if checked then
								n = GREEN_FONT_COLOR_CODE .. n .. FONT_COLOR_CODE_CLOSE
							else
								n = RED_FONT_COLOR_CODE .. n .. FONT_COLOR_CODE_CLOSE
							end
							return n
						end,
						desc = function( info )
							local id = tonumber( info[#info-3] )
							local checked = ArkInventory.db.global.option.sort.data[id].active[info[#info-1]]
							local n = ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_" .. string.upper( info[#info-1] ) .. "_TEXT"]
							if not checked then
								n = n .. "\n\n" .. RED_FONT_COLOR_CODE .. ArkInventory.Localise["CONFIG_SORTMETHOD_NOT_INCLUDED"]
							end
							return n
						end,
						type = "toggle",
						get = function( info )
							local id = tonumber( info[#info-3] )
							return ArkInventory.db.global.option.sort.data[id].active[info[#info-1]]
						end,
						set = function( info, v )
							local id = tonumber( info[#info-3] )
							ArkInventory.db.global.option.sort.data[id].active[info[#info-1]] = v
							ArkInventory.LocationSetValue( nil, "resort", true )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
					up = {
						order = 200,
						name = ArkInventory.Localise["MOVE_UP"],
						desc = function( info )
							return string.format( ArkInventory.Localise["CONFIG_SORTMETHOD_MOVE_UP_TEXT"], LIGHTYELLOW_FONT_COLOR_CODE .. ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_" .. string.upper( info[#info-1] )] .. FONT_COLOR_CODE_CLOSE )
						end,
						type = "execute",
						disabled = function( info )
							local id = tonumber( info[#info-3] )
							local checked = ArkInventory.db.global.option.sort.data[id].active[info[#info-1]]
							return not checked
						end,
						func = function( info )
							local id = tonumber( info[#info-3] )
							ArkInventory.SortKeyMoveUp( id, info[#info-1] )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
					down = {
						order = 300,
						name = ArkInventory.Localise["MOVE_DOWN"],
						desc = function( info )
							return string.format( ArkInventory.Localise["CONFIG_SORTMETHOD_MOVE_DOWN_TEXT"], LIGHTYELLOW_FONT_COLOR_CODE .. ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_" .. string.upper( info[#info-1] )] .. FONT_COLOR_CODE_CLOSE )
						end,
						type = "execute",
						disabled = function( info )
							local id = tonumber( info[#info-3] )
							local checked = ArkInventory.db.global.option.sort.data[id].active[info[#info-1]]
							return not checked
						end,
						func = function( info )
							local id = tonumber( info[#info-3] )
							ArkInventory.SortKeyMoveDown( id, info[#info-1] )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
				},
			}
		end
	end
	
	for id, data in pairs( ArkInventory.db.global.option.sort.data ) do
		
		if data.used then
			
			local n = ""
			if id == 0 then
				n = string.format( " %s (%s)", n, ArkInventory.Localise["DEFAULT"] )
			end
	
			if ArkInventory.Global.Options.CustomSortKeySort then
				n = string.format( "%s [%04i]%s", data.name or "---", id, n )
			else
				n = string.format( "[%04i] %s%s", id, data.name or "---", n )
			end
				
			path[string.format( "%i", id )] = {
				order = 100,
				name = n,
				type = "group",
				args = {
					ren = { 
						order = 100,
						name = ArkInventory.Localise["RENAME"],
						desc = ArkInventory.Localise["CONFIG_SORTMETHOD_RENAME_TEXT"],
						type = "input",
						disabled = ( id == 0 ),
						get = function( )
							return data.name
						end,
						set = function( info, v )
							data.name = v
							ArkInventory.OptionsInitSorting( )
						end,
					},
					del = { 
						order = 200,
						name = ArkInventory.Localise["DELETE"],
						desc = ArkInventory.Localise["CONFIG_SORTMETHOD_DELETE_TEXT"],
						type = "execute",
						disabled = ( id == 0 ),
						func = function( )
							ArkInventory.SortKeyCustomDelete( id, "DELETE" )
							--ArkInventory.OptionsInitCategory( )
						end,
					},
					style = {
						order = 300,
						name = ArkInventory.Localise["STYLE"],
						desc = ArkInventory.Localise["CONFIG_SORTMETHOD_STYLE_TEXT"],
						type = "select",
						disabled = ( id == 0 ),
						values = function( )
							local t = { [1] = ArkInventory.Localise["CONFIG_SORTMETHOD_STYLE_BAGSLOT"], [2] = ArkInventory.Localise["CONFIG_SORTMETHOD_STYLE_USER"] }
							return t
						end,
						get = function( info )
							local v = ArkInventory.db.global.option.sort.data[id].bagslot
							if v then
								v = 1
							else
								v = 2
							end
							return v
						end,
						set = function( info, v )
							local v = v
							if v == 1 then
								v = true
							else
								v = false
							end
							ArkInventory.db.global.option.sort.data[id].bagslot = v
							ArkInventory.LocationSetValue( nil, "resort", true )
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
					direction = {
						order = 400,
						name = ArkInventory.Localise["DIRECTION"],
						desc = ArkInventory.Localise["CONFIG_SORTMETHOD_DIRECTION_TEXT"],
						type = "select",
						disabled = ( id == 0 ),
						values = function( )
							local t = { [1] = ArkInventory.Localise["ASCENDING"], [2] = ArkInventory.Localise["DECENDING"] }
							return t
						end,
						get = function( info )
							local v = ArkInventory.db.global.option.sort.data[id].ascending
							if v then
								v = 1
							else
								v = 2
							end
							return v
						end,
						set = function( info, v )
							local v = v
							if v == 1 then
								v = true
							else
								v = false
							end
							--local loc_id = tonumber( info[#info-2] )
							ArkInventory.db.global.option.sort.data[id].ascending = v
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
					order = {
						order = 500,
						name = ArkInventory.Localise["CONFIG_SORTMETHOD_ORDER"],
						type = "group",
						inline = true,
						hidden = function( info )
							return ArkInventory.db.global.option.sort.data[id].bagslot
						end,
						args = sortorderargs, -- calculated
					},
					reverse = {
						order = 600,
						name = ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_NAME_REVERSE"],
						desc = ArkInventory.Localise["CONFIG_SORTMETHOD_INCLUDE_NAME_REVERSE_TEXT"],
						type = "toggle",
						hidden = function( info )
							return ArkInventory.db.global.option.sort.data[id].bagslot or not ArkInventory.db.global.option.sort.data[id].active.name
						end,
						get = function( info )
							return ArkInventory.db.global.option.sort.data[id].reversed
						end,
						set = function( info, v )
							ArkInventory.db.global.option.sort.data[id].reversed = v
							ArkInventory.Frame_Main_Generate( nil, ArkInventory.Const.Window.Draw.Resort )
						end,
					},
				},
			}
		
		end
		
	end
	
end
	
function ArkInventory.Frame_Config_Hide( )
	ArkInventory.Lib.Dialog:Close( ArkInventory.Const.Frame.Options.Internal )
end
	
function ArkInventory.Frame_Config_Show( )
	ArkInventory.Lib.Dialog:Open( ArkInventory.Const.Frame.Options.Internal )
end

function ArkInventory.Frame_Config_Toggle( )

--	if ARKINV_Search:IsVisible( ) then
--		ArkInventory.Frame_Config_Hide( )
--	else
		ArkInventory.Frame_Config_Show( )
--	end
	
end
